callaway.traits.game: Graph generation based on different vertex types

View source: R/games.R

callaway.traits.gameR Documentation

Graph generation based on different vertex types

Description

[Deprecated]

callaway.traits.game() was renamed to sample_traits_callaway() to create a more consistent API.

Usage

callaway.traits.game(
  nodes,
  types,
  edge.per.step = 1,
  type.dist = rep(1, types),
  pref.matrix = matrix(1, types, types),
  directed = FALSE
)

Arguments

nodes

The number of vertices in the graph.

types

The number of different vertex types.

edge.per.step

The number of edges to add to the graph per time step.

type.dist

The distribution of the vertex types. This is assumed to be stationary in time.

pref.matrix

A matrix giving the preferences of the given vertex types. These should be probabilities, i.e. numbers between zero and one.

directed

Logical constant, whether to generate directed graphs.

Related documentation in the C library

callaway_traits_game()


igraph documentation built on May 4, 2026, 9:07 a.m.