View source: R/centralization.R
| centr_eigen | R Documentation |
See centralize() for a summary of graph centralization.
centr_eigen(
graph,
directed = FALSE,
scale = deprecated(),
options = arpack_defaults(),
normalized = TRUE
)
A named list with the following components:
The node-level centrality scores.
The corresponding eigenvalue.
ARPACK options, see the return value of eigen_centrality() for details.
The graph level centrality index.
The same as above, the theoretical maximum centralization score for a graph with the same number of vertices.
centralization_eigenvector_centrality().
Other centralization related:
centr_betw(),
centr_betw_tmax(),
centr_clo(),
centr_clo_tmax(),
centr_degree(),
centr_degree_tmax(),
centr_eigen_tmax(),
centralize()
# A BA graph is quite centralized
g <- sample_pa(1000, m = 4)
centr_degree(g)$centralization
centr_clo(g, mode = "all")$centralization
centr_betw(g, directed = FALSE)$centralization
centr_eigen(g, directed = FALSE)$centralization
# The most centralized graph according to eigenvector centrality
g0 <- make_graph(c(2, 1), n = 10, dir = FALSE)
g1 <- make_star(10, mode = "undirected")
centr_eigen(g0)$centralization
centr_eigen(g1)$centralization
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.