code.length: Functions to deal with the result of network community...

View source: R/community.R

code.lengthR Documentation

Functions to deal with the result of network community detection

Description

[Deprecated]

code.length() was renamed to code_len() to create a more consistent API.

Usage

code.length(communities)

igraph documentation built on Feb. 12, 2026, 5:08 p.m.