degree.distribution: Degree and degree distribution of the vertices

View source: R/structural-properties.R

degree.distributionR Documentation

Degree and degree distribution of the vertices

Description

[Deprecated]

degree.distribution() was renamed to degree_distribution() to create a more consistent API.

Usage

degree.distribution(graph, cumulative = FALSE, ...)

Arguments

graph

The graph to analyze.

cumulative

Logical; whether the cumulative degree distribution is to be calculated.

...

These dots are for future extensions and must be empty.

Related documentation in the C library

degree(), vcount()


igraph documentation built on May 4, 2026, 9:07 a.m.