delete.edges: Delete edges from a graph

View source: R/interface.R

delete.edgesR Documentation

Delete edges from a graph

Description

[Deprecated]

delete.edges() was renamed to delete_edges() to create a more consistent API.

Usage

delete.edges(graph, edges)

Arguments

graph

The input graph.

edges

The edges to remove, specified as an edge sequence. Typically this is either a numeric vector containing edge IDs, or a character vector containing the IDs or names of the source and target vertices, separated by |

Related documentation in the C library

delete_edges(), get_eids(), edges(), ecount(), vcount()


igraph documentation built on April 21, 2026, 5:06 p.m.