from_incidence_matrix: Graph from incidence matrix

View source: R/incidence.R

from_incidence_matrixR Documentation

Graph from incidence matrix

Description

[Deprecated]

graph_from_incidence_matrix() was renamed to graph_from_biadjacency_matrix() to create a more consistent API.

Usage

from_incidence_matrix(...)

Details

Some authors refer to the bipartite adjacency matrix as the "bipartite incidence matrix". igraph 1.6.0 and later does not use this naming to avoid confusion with the edge-vertex incidence matrix.

Related documentation in the C library

biadjacency(), create(), empty(), vcount(), famous(), simplify(), edges(), get_eids(), ecount()


igraph documentation built on May 4, 2026, 9:07 a.m.