get.edge.attribute: Query edge attributes of a graph

View source: R/attributes.R

get.edge.attributeR Documentation

Query edge attributes of a graph

Description

[Deprecated]

get.edge.attribute() was renamed to edge_attr() to create a more consistent API.

Usage

get.edge.attribute(graph, name, index = E(graph))

Arguments

graph

The graph

name

The name of the attribute to query. If missing, then all edge attributes are returned in a list.

index

An optional edge sequence to query edge attributes for a subset of edges.

Related documentation in the C library

edges(), get_eids(), vcount(), ecount()


igraph documentation built on May 4, 2026, 9:07 a.m.