graph.motifs: Graph motifs

View source: R/motifs.R

graph.motifsR Documentation

Graph motifs

Description

[Deprecated]

graph.motifs() was renamed to motifs() to create a more consistent API.

Usage

graph.motifs(graph, size = 3, cut.prob = rep(0, size))

Arguments

graph

Graph object, the input graph.

size

The size of the motif, currently sizes 3 and 4 are supported in directed graphs and sizes 3 to 6 in undirected graphs.

cut.prob

Numeric vector giving the probabilities that the search graph is cut at a certain level. Its length should be the same as the size of the motif (the size argument). If ⁠rep(0, size))⁠, the default, no cuts are made.

Related documentation in the C library

motifs_randesu(), motifs_randesu_callback_closure()


igraph documentation built on May 4, 2026, 9:07 a.m.