has.multiple: Find the multiple or loop edges in a graph

View source: R/structural-properties.R

has.multipleR Documentation

Find the multiple or loop edges in a graph

Description

[Deprecated]

has.multiple() was renamed to any_multiple() to create a more consistent API.

Usage

has.multiple(graph)

Arguments

graph

The input graph.

Related documentation in the C library

has_multiple()


igraph documentation built on May 4, 2026, 9:07 a.m.