hrg.create: Create a hierarchical random graph from an igraph graph

View source: R/hrg.R

hrg.createR Documentation

Create a hierarchical random graph from an igraph graph

Description

[Deprecated]

hrg.create() was renamed to hrg() to create a more consistent API.

Usage

hrg.create(graph, prob)

Arguments

graph

The igraph graph to create the HRG from.

prob

A vector of probabilities, one for each vertex, in the order of vertex ids.

Related documentation in the C library

hrg_create()


igraph documentation built on May 4, 2026, 9:07 a.m.