is.hierarchical: Functions to deal with the result of network community...

View source: R/community.R

is.hierarchicalR Documentation

Functions to deal with the result of network community detection

Description

[Deprecated]

is.hierarchical() was renamed to is_hierarchical() to create a more consistent API.

Usage

is.hierarchical(communities)

igraph documentation built on Feb. 12, 2026, 5:08 p.m.