is.multiple: Find the multiple or loop edges in a graph

View source: R/structural-properties.R

is.multipleR Documentation

Find the multiple or loop edges in a graph

Description

[Deprecated]

is.multiple() was renamed to which_multiple() to create a more consistent API.

Usage

is.multiple(graph, eids = E(graph))

Arguments

graph

The input graph.

eids

The edges to which the query is restricted. By default this is all edges in the graph.

Related documentation in the C library

is_multiple(), edges(), get_eids(), vcount(), ecount()


igraph documentation built on May 4, 2026, 9:07 a.m.