| isomorphisms | R Documentation |
Calculate all isomorphic mappings between the vertices of two graphs
isomorphisms(graph1, graph2, method = "vf2", ..., callback = NULL)
graph1 |
The first graph. |
graph2 |
The second graph. |
method |
Currently only ‘vf2’ is supported, see
|
... |
Extra arguments, passed to the various methods. |
callback |
Optional callback function to call for each isomorphism found.
If provided, the function should accept two arguments: Important limitation: Callback functions must NOT call any igraph
functions (including simple queries like |
If callback is NULL, returns a list of vertex sequences, corresponding
to all mappings from the first graph to the second. If callback is provided,
returns NULL invisibly.
get_isomorphisms_vf2(), vcount(), edges(), get_eids(), ecount()
Other graph isomorphism:
canonical_permutation(),
count_isomorphisms(),
count_subgraph_isomorphisms(),
graph_from_isomorphism_class(),
isomorphic(),
isomorphism_class(),
subgraph_isomorphic(),
subgraph_isomorphisms()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.