make_full_citation_graph: Create a complete (full) citation graph

View source: R/make.R

make_full_citation_graphR Documentation

Create a complete (full) citation graph

Description

make_full_citation_graph() creates a full citation graph. This is a directed graph, where every i->j edge is present if and only if j<i. If directed=FALSE then the graph is just a full graph.

Usage

make_full_citation_graph(n, directed = TRUE)

full_citation_graph(n, directed = TRUE)

Arguments

n

The number of vertices.

directed

Whether to create a directed graph.

Value

An igraph graph.

Related documentation in the C library

full_citation()

See Also

Other deterministic constructors: graph_from_atlas(), graph_from_edgelist(), graph_from_literal(), make_(), make_chordal_ring(), make_circulant(), make_empty_graph(), make_full_graph(), make_full_multipartite(), make_graph(), make_lattice(), make_ring(), make_star(), make_tree(), make_turan(), make_wheel()

Examples

print_all(make_full_citation_graph(10))

igraph documentation built on May 4, 2026, 9:07 a.m.