make_wheel: Create a wheel graph

View source: R/make.R

make_wheelR Documentation

Create a wheel graph

Description

[Experimental]

A wheel graph is created by connecting a center vertex to all vertices of a cycle graph. A wheel graph on n vertices can be thought of as a wheel with n - 1 spokes. The cycle graph part makes up the rim, while the star graph part adds the spokes.

Note that the two and three-vertex wheel graphs are non-simple: The two-vertex wheel graph contains a self-loop, while the three-vertex wheel graph contains parallel edges (a 1-cycle and a 2-cycle, respectively).

Usage

make_wheel(n, ..., mode = c("in", "out", "mutual", "undirected"), center = 1)

wheel(n, ..., mode = c("in", "out", "mutual", "undirected"), center = 1)

Arguments

n

Number of vertices.

...

These dots are for future extensions and must be empty.

mode

It defines the direction of the edges. ⁠in⁠: the edges point to the center, out: the edges point from the center, mutual: a directed wheel is created with mutual edges, undirected: the edges are undirected.

center

ID of the center vertex.

Value

An igraph graph.

Related documentation in the C library

wheel()

See Also

Other deterministic constructors: graph_from_atlas(), graph_from_edgelist(), graph_from_literal(), make_(), make_chordal_ring(), make_circulant(), make_empty_graph(), make_full_citation_graph(), make_full_graph(), make_full_multipartite(), make_graph(), make_lattice(), make_ring(), make_star(), make_tree(), make_turan()

Examples

make_wheel(10, mode = "out")
make_wheel(5, mode = "undirected")

igraph documentation built on April 21, 2026, 5:06 p.m.