set.edge.attribute: Set edge attributes

View source: R/attributes.R

set.edge.attributeR Documentation

Set edge attributes

Description

[Deprecated]

set.edge.attribute() was renamed to set_edge_attr() to create a more consistent API.

Usage

set.edge.attribute(graph, name, index = E(graph), value)

Arguments

graph

The graph

name

The name of the attribute to set.

index

An optional edge sequence to set the attributes of a subset of edges.

value

The new value of the attribute for all (or index) edges. If NULL, the input is returned unchanged.

Related documentation in the C library

edges(), get_eids(), vcount(), ecount()


igraph documentation built on May 4, 2026, 9:07 a.m.