count.multiple: Find the multiple or loop edges in a graph

View source: R/structural-properties.R

count.multipleR Documentation

Find the multiple or loop edges in a graph

Description

[Deprecated]

count.multiple() was renamed to count_multiple() to create a more consistent API.

Usage

count.multiple(graph, eids = E(graph))

Arguments

graph

The input graph.

eids

The edges to which the query is restricted. By default this is all edges in the graph.

Related documentation in the C library

count_multiple(), edges(), get_eids(), vcount(), ecount()


igraph documentation built on April 21, 2026, 5:06 p.m.