| graph_from_lcf | R Documentation |
LCF is short for Lederberg-Coxeter-Frucht, it is a concise notation for 3-regular Hamiltonian graphs. It constists of three parameters, the number of vertices in the graph, a list of shifts giving additional edges to a cycle backbone and another integer giving how many times the shifts should be performed. See https://mathworld.wolfram.com/LCFNotation.html for details.
graph_from_lcf(shifts, ..., n = NULL, repeats = 1L)
shifts |
Integer vector, the shifts. |
... |
These dots are for future extensions and must be empty. |
n |
Integer, the number of vertices in the graph. If |
repeats |
Integer constant, how many times to repeat the shifts. |
A graph object.
Gabor Csardi csardi.gabor@gmail.com
make_graph() can create arbitrary graphs, see also the other
functions on the its manual page for creating special graphs.
# This is the Franklin graph:
g1 <- graph_from_lcf(shifts = c(5L, -5L), n = 12L, repeats = 6L)
g2 <- make_graph("Franklin")
isomorphic(g1, g2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.