| invalidate_cache | R Documentation |
igraph graphs cache some basic properties (such as whether the graph is a DAG or whether it is simple) in an internal data structure for faster repeated queries. This function invalidates the cache, forcing a recalculation of the cached properties the next time they are needed.
invalidate_cache(graph)
graph |
The graph whose cache is to be invalidated. |
You should not need to call this function during normal usage; however, it
may be useful for debugging cache-related issues. A tell-tale sign of an
invalid cache entry is when the result of a cached function (such as
is_dag() or is_simple()) changes after calling
this function.
The graph with its cache invalidated. Since the graph is modified in place in R as well, you can also ignore the return value.
g <- make_ring(10)
# Cache is populated when calling is_simple()
is_simple(g)
# Invalidate cache (for debugging purposes)
invalidate_cache(g)
# Result should be the same
is_simple(g)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.