is.bipartite: Checks whether the graph has a vertex attribute called 'type'

View source: R/attributes.R

is.bipartiteR Documentation

Checks whether the graph has a vertex attribute called type

Description

[Deprecated]

is.bipartite() was renamed to is_bipartite() to create a more consistent API.

Usage

is.bipartite(graph)

Arguments

graph

The input graph


igraph documentation built on Feb. 12, 2026, 5:08 p.m.