is.loop: Find the multiple or loop edges in a graph

View source: R/structural-properties.R

is.loopR Documentation

Find the multiple or loop edges in a graph

Description

[Deprecated]

is.loop() was renamed to which_loop() to create a more consistent API.

Usage

is.loop(graph, eids = E(graph))

Arguments

graph

The input graph.

eids

The edges to which the query is restricted. By default this is all edges in the graph.

Related documentation in the C library

is_loop(), edges(), get_eids(), vcount(), ecount()


igraph documentation built on April 21, 2026, 5:06 p.m.