powered by
This functions starts an experimental GUI to some igraph functions. The GUI was written in Tcl/Tk, so it is cross platform.
tkigraph()
Returns NULL, invisibly.
NULL
Gabor Csardi [email protected]
tkigraph has its own online help system, please see that for the details about how to use it.
tkigraph
tkplot for interactive plotting of graphs.
tkplot